==> node-jest_27.2.1~ds%2B~cs67.45.24.orig.tar.xz: jest-27.2.1/e2e/__tests__/nativeEsm.test.ts <==
/**
 * Copyright (c) Facebook, Inc. and its affiliates. All Rights Reserved.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */

import {resolve} from 'path';
import wrap from 'jest-snapshot-serializer-raw';
import {onNodeVersions} from '@jest/test-utils';
import {extractSummary} from '../Utils';
import runJest, {getConfig} from '../runJest';

const DIR = resolve(__dirname, '../native-esm');

test('test config is without transform', () => {
  const {configs} = getConfig(DIR);

  expect(configs).toHaveLength(1);
  expect(configs[0].transform).toEqual([]);
});

// The versions where vm.Module exists and commonjs with "exports" is not broken
onNodeVersions('>=12.16.0', () => {
  test('runs test with native ESM', () => {
    const {exitCode, stderr, stdout} = runJest(DIR, ['native-esm.test.js'], {
      nodeOptions: '--experimental-vm-modules --no-warnings',
    });

    const {summary} = extractSummary(stderr);

    expect(wrap(summary)).toMatchSnapshot();
    expect(stdout).toBe('');
    expect(exitCode).toBe(0);
  });
});

// The versions where TLA is supported
onNodeVersions('>=14.3.0', () => {
  test('supports top-level await', () => {
    const {exitCode, stderr, stdout} = runJest(
      DIR,
      ['native-esm.tla.test.js'],
      {nodeOptions: '--experimental-vm-modules --no-warnings'},
    );

    const {summary} = extractSummary(stderr);

    expect(wrap(summary)).toMatchSnapshot();
    expect(stdout).toBe('');
    expect(exitCode).toBe(0);
  });
});

==> node-jest_28.1.3~ds%2B~cs70.48.29.orig.tar.xz: jest-28.1.3/e2e/__tests__/nativeEsm.test.ts <==
/**
 * Copyright (c) Facebook, Inc. and its affiliates. All Rights Reserved.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */

import {resolve} from 'path';
import {onNodeVersions} from '@jest/test-utils';
import {extractSummary} from '../Utils';
import runJest, {getConfig} from '../runJest';

const DIR = resolve(__dirname, '../native-esm');

test('test config is without transform', () => {
  const {configs} = getConfig(DIR);

  expect(configs).toHaveLength(1);
  expect(configs[0].transform).toEqual([]);
});

// The versions where vm.Module exists and commonjs with "exports" is not broken
onNodeVersions('>=12.16.0', () => {
  test('runs test with native ESM', () => {
    const {exitCode, stderr, stdout} = runJest(DIR, ['native-esm.test.js'], {
      nodeOptions: '--experimental-vm-modules --no-warnings',
    });

    const {summary} = extractSummary(stderr);

    expect(summary).toMatchSnapshot();
    expect(stdout).toBe('');
    expect(exitCode).toBe(0);
  });
});

// The versions where TLA is supported
onNodeVersions('>=14.3.0', () => {
  test('supports top-level await', () => {
    const {exitCode, stderr, stdout} = runJest(
      DIR,
      ['native-esm.tla.test.js'],
      {nodeOptions: '--experimental-vm-modules --no-warnings'},
    );

    const {summary} = extractSummary(stderr);

    expect(summary).toMatchSnapshot();
    expect(stdout).toBe('');
    expect(exitCode).toBe(0);
  });
});
